@@ -67,7 +67,7 @@ def one_hot(data):
     #print(onehot_encoded)
     return(integer_encoded, final_one_hot_encoded,label_encoder)
 ##############################################################################
-class feature():
+class feature(object):
 
     def __init__(self, data_vect, name):
         self.labels = list(data_vect)
@@ -222,7 +222,7 @@ def log_loss(y_true, y_pred, eps = 1e-15):
     return(ll)
 
 
-class categorical_ome():
+class categorical_ome(object):
     """ this class is for any categorical ome """
     def __init__(self, in_mat, path = None, name = None, plot = False, include_subjects = None):
         ## rows are subjects, columns are features
@@ -764,6 +764,51 @@ class categorical_ome():
 
         return
 
+    def __str__(self):
+        out_str = "MANAcat object"
+        out_str += "\nObjects of interest:"
+        out_str += "\n\t<object>.affinity_matrix: The affinity matrix for this input dataset."
+        # out_str += "\n\t<object>.all_col_dim: "
+        # out_str += "\n\t<object>.all_diff: "
+        # out_str += "\n\t<object>.all_encodings: "
+        out_str += "\n\t<object>.all_feature_names: A list of all the names of the features.\n\t\t(the selected ones if this is a feature selected categorical ome)"
+        out_str += "\n\t<object>.all_features: A list of feature objects."
+        out_str += "\n\t<object>.all_log_loss: The list of log-losses for all subject-subject pairs."
+        # out_str += "\n\t<object>.cross_feature_mutual_info: "
+        # out_str += "\n\t<object>.do_pairwise: "
+        # out_str += "\n\t<object>.do_stats: "
+        out_str += "\n\t<object>.feature_names: The names of the features"
+        # out_str += "\n\t<object>.filter_out_nones: "
+        out_str += "\n\t<object>.full_cat_data: The dataset."
+        # out_str += "\n\t<object>.get_cross_feature_info: "
+        # out_str += "\n\t<object>.get_feature_by_group_contingency_table: "
+        # out_str += "\n\t<object>.get_good_features: "
+        # out_str += "\n\t<object>.get_log_loss: "
+        # out_str += "\n\t<object>.get_noise_factor: "
+        # out_str += "\n\t<object>.get_two_group_chi: "
+        # out_str += "\n\t<object>.max_col_dim: "
+        # out_str += "\n\t<object>.max_of_min_diff: "
+        # out_str += "\n\t<object>.min_diff: "
+        out_str += "\n\t<object>.name: The name of this categorical ome."
+        out_str += "\n\t<object>.num_features: The number of features. (if feature selection\n\t\twas done, then this is the number of selected features)"
+        out_str += "\n\t<object>.num_subjects: The number of subjects"
+        out_str += "\n\t<object>.original_mat: The original dataset"
+        # out_str += "\n\t<object>.plot: "
+        # out_str += "\n\t<object>.plot_all_and_good_features: "
+        # out_str += "\n\t<object>.plot_heatmaps: "
+        # out_str += "\n\t<object>.process_cat_ome: "
+        # out_str += "\n\t<object>.randomized_original_mat: "
+        # out_str += "\n\t<object>.real_mi_mat: "
+        # out_str += "\n\t<object>.single_fisher: "
+        # out_str += "\n\t<object>.smooth_log_loss: "
+        out_str += "\n\t<object>.subjects: The list of subject IDs (same order as affinity matrix)"
+        # out_str += "\n\t<object>.summarize_pairwise_group_differences: "
+        return(out_str)
+
+    def __repr__(self):
+        #return("ap_obj('""')")
+        return("MANAclust categorical-ome object")
+
 
 ##############################################################################
 
