@@ -147,7 +147,7 @@ def do_clust(meta_ome, am = None, full = False):
     label_dict = {subj:group for subj, group in subj_label_pairs}
     return(labels, subj_label_pairs, label_dict)
 
-class cluster_omes():
+class cluster_omes(object):
     def __init__(self, cat_omes = None, num_omes = None, out_dir=None, do_plot=False, missing_str = 'NA', processes = 1, bin_size = 5000, force = True, no_h5 = False, store_16bit = False, process_mem = None):
         if cat_omes == None and num_omes == None:
             print("we need to have some kind of omes fed in. Try something like cluster_omes(cat_omes = ['pat_characteristics.txt'], num_omes = ['microbiome.txt','transcriptome.txt'])")
@@ -238,6 +238,33 @@ class cluster_omes():
 
             self.labels, self.label_pairs, self.label_dict = do_clust(self, full=False)
             self.labels_full, self.label_pairs_full, self.label_dict_full = do_clust(self, full=True)
+    def __str__(self):
+        out_str = "MANAclust object"
+        out_str += "\nObjects of interest:"
+        out_str += "\n\t<object>.affinity_matrices: The '3D stack' of all affinity matrices that went\n\t\tinto making the final affinity matrix. These are in the same order as the input,\n\t\twith categorical datasets first, then numeric."
+        out_str += "\n\t<object>.affinity_matrices_full: Same as the above, but without feature selection"
+        out_str += "\n\t<object>.affinity_matrix: The final merged affinity matrix from which the \n\t\tfinal clusters were determined. Note that the subject IDs\n\t\t(in the same orders as the rows/columns) is in <object>.all_subjects"
+        out_str += "\n\t<object>.affinity_matrix_full: Same as the above, but without feature selection"
+        out_str += "\n\t<object>.all_subjects: The list of Subject IDs that line up with the affinity matrices."
+        out_str += "\n\t<object>.cat_ome_files: The original list of files fed in for clustering."
+        out_str += "\n\t<object>.cat_omes: A list of all categorical ome object files that you \n\t\tcan explore, just like this one."
+        out_str += "\n\t<object>.cat_omes_full: Same as the above, but without feature selection"
+        out_str += "\n\t<object>.label_dict: A dictionary with keys corresponding to subject IDs, and "
+        out_str += "\n\t<object>.label_dict_full: Same as the above, but without feature selection"
+        # out_str += "\n\t<object>.label_pairs: "
+        # out_str += "\n\t<object>.label_pairs_full: Same as the above, but without feature selection"
+        out_str += "\n\t<object>.labels: A list of the final cluster IDs \n\t\t(sorted in line with the <object>.all_subjects entries)"
+        out_str += "\n\t<object>.labels_full: Same as the above, but without feature selection"
+        out_str += "\n\t<object>.num_ome_files: The input files for the numeric omes."
+        out_str += "\n\t<object>.num_omes: A list of all categorical ome object files that you \n\t\tcan explore, just like this one."
+        out_str += "\n\t<object>.num_omes_full: Same as the above, but without feature selection"
+        # out_str += "\n\t<object>.out_dir: "
+        out_str += "\n\t<object>.subject_idx_hash: A potentially useful dictionary object, with \n\t\tthe keys corresponding to the subject IDs, returning the index within \n\t\tthe affinity matrix that the subject belongs to."
+        return(out_str)
+
+    def __repr__(self):
+        #return("ap_obj('""')")
+        return("MANAclust meta-ome object")
 
 
 def quantileNormalize(in_mat):
@@ -683,6 +710,7 @@ def mana_clust(out_dir,
                                   test_num = test_num_omes,
                                   one_hot = args.one_hot)
     make_webpage(out_dir)
+    print("\n\n\n",meta_ome)
     return(meta_ome)
 
 
