@@ -231,7 +231,7 @@ def get_shuffled(num_ome, bin_size = 5000):
 ############################################################################
 
 
-class num_ome():
+class num_ome(object):
     def __init__(self, in_mat, feature_names, sample_names, 
                  name=None, 
                  all_features=False,
@@ -927,6 +927,61 @@ class num_ome():
         return
 
 
+    def __str__(self):
+        out_str = "MANAnum object"
+        out_str += "\nObjects of interest:"
+        # out_str += "\n\t<object>.add_to_spear_mat: "
+        out_str += "\n\t<object>.affinity_matrix: The affinity matrix for this input dataset."
+        # out_str += "\n\t<object>.all_feature_names: "
+        out_str += "\n\t<object>.all_features: A True/False variable corresponding to whether or not \n\t\tthis input dataset underwent feature selection or not. When all_features is True,\n\t\tthis means feature selection was foregone & all features were included."
+        out_str += "\n\t<object>.anti_cor_indices: The indices that correspond to the selected features."
+        # out_str += "\n\t<object>.bin_size: "
+        # out_str += "\n\t<object>.bins: "
+        # out_str += "\n\t<object>.do_pairwise: "
+        # out_str += "\n\t<object>.do_parallel_pairwise: "
+        # out_str += "\n\t<object>.do_stats: "
+        # out_str += "\n\t<object>.expected_neg_cor: "
+        # out_str += "\n\t<object>.expected_prob: "
+        out_str += "\n\t<object>.feature_names: The name of all features (selected and not). If you want\n\t\tto look at which features were selected do this:\n\t\t\t<object>.feature_names[<object>.anti_cor_indices]"
+        # out_str += "\n\t<object>.force: "
+        # out_str += "\n\t<object>.get_affinity_matrix: "
+        # out_str += "\n\t<object>.get_anti_cor_feature_mat: "
+        # out_str += "\n\t<object>.get_anti_cor_features: "
+        # out_str += "\n\t<object>.get_anti_cor_features_no_h5: "
+        # out_str += "\n\t<object>.get_anti_correlated_features: "
+        # out_str += "\n\t<object>.get_bins: "
+        # out_str += "\n\t<object>.get_good_features_and_norm: "
+        # out_str += "\n\t<object>.get_process_lines: "
+        # out_str += "\n\t<object>.get_variant_indices: "
+        # out_str += "\n\t<object>.hdf5_spear_out_file: "
+        out_str += "\n\t<object>.in_mat: The input dataset matrix"
+        out_str += "\n\t<object>.infile: The input file that generated this object."
+        # out_str += "\n\t<object>.is_variant_feature: "
+        # out_str += "\n\t<object>.make_spearman_out: "
+        # out_str += "\n\t<object>.multiplier: "
+        out_str += "\n\t<object>.name: The name of this dataset."
+        # out_str += "\n\t<object>.neg_cutoff: "
+        # out_str += "\n\t<object>.no_h5: "
+        # out_str += "\n\t<object>.out_dir: "
+        out_str += "\n\t<object>.passing: A True/False vector corresponding to whether or not the\n\t\tgiven feature was selected for clustering."
+        # out_str += "\n\t<object>.plot_all_and_good_features: "
+        # out_str += "\n\t<object>.process_mem: "
+        # out_str += "\n\t<object>.processes: "
+        # out_str += "\n\t<object>.ray_aov: "
+        # out_str += "\n\t<object>.sample_names: "
+        # out_str += "\n\t<object>.set_spear_bins: "
+        # out_str += "\n\t<object>.sig_neg_cor: "
+        # out_str += "\n\t<object>.single_anova: "
+        out_str += "\n\t<object>.subjects: All Subject IDs"
+        # out_str += "\n\t<object>.summarize_pairwise_group_differences: "
+        # out_str += "\n\t<object>.total_neg_cor: "
+        return(out_str)
+
+    def __repr__(self):
+        #return("ap_obj('""')")
+        return("MANAclust numeric_ome object")
+
+
 
 ########################################################################
 def filter_num_subjects(in_mat_full, include_subjects):
